# macros for sysvinit transition - should be equal to
# sysvinit %version-%release-plus-1
%define sysvinit_version 2.87
%define sysvinit_release %mkrel 9

Summary:	A System and Session Manager
Name:		systemd
Version:	18
Release:	%mkrel 1
License:	GPLv2+
Group:		System/Configuration/Boot and Init
Url:		http://www.freedesktop.org/wiki/Software/systemd
Source0:	http://www.freedesktop.org/software/systemd/%{name}-%{version}.tar.bz2

# (bor) for now we use messabus service to start D-Bus
# Patch4:		0005-Set-special-D-Bus-service-to-messagebus.service.patch
# (bor) adapt vconsole service to Mandriva configuration
# Patch5:		0006-Adapt-vconsole-setup-to-Mandriva-configuration-based.patch
# (bor) adapt locale setup to Mandriva configuration
Patch6:		0007-Fully-support-all-i18n-environments-in-Mandriva.patch
# (bor) distinguish between network and $network to break dependency loop
Patch7:		0008-Use-network-for-special-network-service.patch
# (bor) support libnotify < 0.7; combines d0ef22 and ab85c2 (GIT)
#Patch12:	0001-gnome-ask-password-agent-also-support-libnotify-0.7-.patch
# (bor) take welcome message from /etc/release (adapted by blino)
Patch13:       0001-Use-etc-release-to-show-boot-welcome-messag.patch

BuildRequires:	dbus-devel >= 1.4.0
BuildRequires:	libudev-devel >= 160
BuildRequires:	libcap-devel
BuildRequires:	tcp_wrappers-devel
BuildRequires:	pam-devel
BuildRequires:	dbus-glib-devel
BuildRequires:	vala >= 0.9
BuildRequires:	gtk2-devel  
BuildRequires:	glib2-devel
BuildRequires:	libnotify-devel
Requires:	systemd-units = %{version}-%{release}
Requires:	dbus >= 1.3.2
Requires:	udev >= 160
Requires:	initscripts >= 9.21-3
Requires:	util-linux-ng >= 2.18
# TODO for P12, remove when it is removed
BuildRequires:	automake 
BuildRequires:	autoconf

%description
systemd is a system and session manager for Linux, compatible with
SysV and LSB init scripts. systemd provides aggressive parallelization
capabilities, uses socket and D-Bus activation for starting services,
offers on-demand starting of daemons, keeps track of processes using
Linux cgroups, supports snapshotting and restoring of the system
state, maintains mount and automount points and implements an
elaborate transactional dependency-based service control logic. It can
work as a drop-in replacement for sysvinit.

%package units
Summary:	Configuration files, directories and installation tool for systemd
Group:		System/Configuration/Boot and Init
Requires:	%{name} = %{version}-%{release}

%description units
Basic configuration files, directories and installation tool for the systemd
system and session manager.

%package gtk
Summary:        Graphical frontend for systemd
Group:          System/Configuration/Boot and Init
Requires:       %{name} = %{version}-%{release}

%description gtk
Graphical front-end for systemd.

%package sysvinit
Summary:        System V init tools
Group:          System/Configuration/Boot and Init
Requires:       %{name} = %{version}-%{release}
# (eugeni) systemd should work as a drop-in replacement for sysvinit, but not obsolete it
Provides:       sysvinit = %sysvinit_version-%sysvinit_release, SysVinit = %sysvinit_release-%sysvinit_release
Conflicts:      sysvinit < %sysvinit_version-%sysvinit_release, SysVinit < %sysvinit_release-%sysvinit_release

%description sysvinit
Drop-in replacement for the System V init tools of systemd.

%prep
%setup -q
%apply_patches
find src/ -name "*.vala" -exec touch '{}' \;

%build
# TODO for P12, remove when it is removed
automake -c -f
autoconf
%configure2_5x \
	--with-rootdir= \
	--with-distro=fedora \
	--with-sysvinit-path=%{_initrddir} \
	--with-sysvrcd-path=%{_sysconfdir}/rc.d \
	--with-syslog-service=rsyslog.service

%make

%install
rm -rf %{buildroot}

%makeinstall_std
find %{buildroot} \( -name '*.a' -o -name '*.la' \) -exec rm {} \;

# Create SysV compatibility symlinks. systemctl/systemd are smart
# enough to detect in which way they are called.
mkdir -p %{buildroot}/sbin
ln -s ../bin/systemd %{buildroot}/sbin/init
ln -s ../bin/systemctl %{buildroot}/sbin/reboot
ln -s ../bin/systemctl %{buildroot}/sbin/halt
ln -s ../bin/systemctl %{buildroot}/sbin/poweroff
ln -s ../bin/systemctl %{buildroot}/sbin/shutdown
ln -s ../bin/systemctl %{buildroot}/sbin/telinit
ln -s ../bin/systemctl %{buildroot}/sbin/runlevel

# We create all wants links manually at installation time to make sure
# they are not owned and hence overriden by rpm after the used deleted
# them.
rm -r %{buildroot}%{_sysconfdir}/systemd/system/*.target.wants
rm -f %{buildroot}%{_sysconfdir}/systemd/system/display-manager.service

# And the default symlink we generate automatically based on inittab
rm -f %{buildroot}%{_sysconfdir}/systemd/system/default.target

# The following services are currently executed by rc.sysinit
pushd %{buildroot}/lib/systemd/system/basic.target.wants && {
	rm -f sysctl.service
	rm -f systemd-modules-load.service
	rm -f systemd-tmpfiles.service
	rm -f systemd-tmpfiles-clean.timer
popd
}

# The following services are currently installed by initscripts
pushd %{buildroot}/lib/systemd/system/graphical.target.wants && {
	rm -f display-manager.service
popd
}

# The following services are currently executed by rc.sysinit
pushd %{buildroot}/lib/systemd/system/local-fs.target.wants && {
	rm -f cryptsetup.target
	rm -f fsck-root.service
	rm -f remount-rootfs.service
	rm -f systemd-remount-api-vfs.service
	rm -f var-lock.mount
	rm -f var-run.mount
popd
}

# The following services are currently installed by initscripts
pushd %{buildroot}/lib/systemd/system/multi-user.target.wants && {
	rm -f rc-local.service
	rm -f systemd-ask-password-wall.path
popd
}

# The following services are currently executed by rc.sysinit
pushd %{buildroot}/lib/systemd/system/sysinit.target.wants && {
	rm -f systemd-ask-password-console.path
	rm -f systemd-modules-load.service
	rm -f systemd-random-seed-load.service
	rm -f systemd-sysctl.service
	rm -f systemd-tmpfiles-setup.service
popd
}

# The following services are currently part of initscripts
pushd %{buildroot}/lib/systemd/system && {
	rm -f default.target
	rm -f display-manager.service
	rm -f prefdm.service
	rm -f rc-local.service
	rm -f single.service
	rm -f sysinit.service
popd
}

# (bor) For now mounts are performed by initscripts (Fedora)
sed -i -e 's/^#MountAuto=yes$/MountAuto=no/' \
        -e 's/^#SwapAuto=yes$/SwapAuto=no/' %{buildroot}/etc/systemd/system.conf

# (bor) make sure we own directory for bluez to install service
mkdir -p %{buildroot}/lib/systemd/system/bluetooth.target.wants

%clean
rm -rf %{buildroot}

%triggerin -- glibc
# reexec daemon on self or glibc update to avoid busy / on shutdown
# trigger is executed on both self and target install so no need to have
# extra own post
if [ $1 -ge 2 -o $2 -ge 2 ] ; then
	/bin/systemctl daemon-reexec 2>&1 || :
fi

%post units
if [ $1 -eq 1 ] ; then
        # Try to read default runlevel from the old inittab if it exists
        runlevel=$(/bin/awk -F ':' '$3 == "initdefault" && $1 !~ "^#" { print $2 }' /etc/inittab 2> /dev/null)
        if [ -z "$runlevel" ] ; then
                target="/lib/systemd/system/graphical.target"
        else
                target="/lib/systemd/system/runlevel$runlevel.target"
        fi

        # And symlink what we found to the new-style default.target
        /bin/ln -sf "$target" %{_sysconfdir}/systemd/system/default.target 2>&1 || :

        # Enable the services we install by default.
	# (bor) do not enable prefdm.service, we start it in initscript
        /bin/systemctl enable \
                getty@.service \
                rc-local.service \
                remote-fs.target 2>&1 || :
fi

%preun units
if [ $1 -eq 0 ] ; then
        /bin/systemctl disable \
                getty@.service \
                rc-local.service \
                remote-fs.target 2>&1 || :

        /bin/rm -f /etc/systemd/system/default.target 2>&1 || :
fi

%postun units
if [ $1 -ge 1 ] ; then
        /bin/systemctl daemon-reload 2>&1 || :
fi

%files
%defattr(-,root,root)
%config(noreplace) %{_sysconfdir}/dbus-1/system.d/org.freedesktop.systemd1.conf
%config(noreplace) %{_sysconfdir}/systemd/system.conf
%dir %{_sysconfdir}/systemd/user
%{_sysconfdir}/xdg/systemd
/bin/systemd
/bin/systemd-ask-password
/bin/systemd-notify
/bin/systemd-tmpfiles
/bin/systemd-tty-ask-password-agent
%dir /lib/systemd
/lib/systemd/systemd-*
/lib/udev/rules.d/*.rules
/%{_lib}/security/pam_systemd.so
%{_bindir}/systemd-cgls
%{_mandir}/man1/systemd.*
%{_mandir}/man1/systemd-notify.*
%{_mandir}/man1/systemd-cgls.*
%{_mandir}/man3/*
%{_mandir}/man5/*
%{_mandir}/man7/*
%{_mandir}/man8/pam_systemd.*
%{_mandir}/man8/systemd-tmpfiles.*
%{_datadir}/systemd
%{_datadir}/dbus-1/services/org.freedesktop.systemd1.service
%{_datadir}/dbus-1/system-services/org.freedesktop.systemd1.service
%{_datadir}/dbus-1/interfaces/org.freedesktop.systemd1.*.xml
%{_datadir}/polkit-1/actions/org.freedesktop.systemd1.policy
%{_docdir}/systemd

%files units
%defattr(-,root,root)
/bin/systemctl
%dir %{_sysconfdir}/systemd
%dir %{_sysconfdir}/systemd/system
%dir %{_sysconfdir}/tmpfiles.d
%{_sysconfdir}/bash_completion.d/systemctl-bash-completion.sh
%config(noreplace) %{_sysconfdir}/tmpfiles.d/*.conf
/lib/systemd/system
%{_mandir}/man1/systemctl.*
%{_datadir}/pkgconfig/systemd.pc

%files gtk
%defattr(-,root,root)
%{_bindir}/systemadm
%{_bindir}/systemd-gnome-ask-password-agent
%{_mandir}/man1/systemadm.*

%files sysvinit
%defattr(-,root,root,-)
/sbin/init
/sbin/reboot
/sbin/halt
/sbin/poweroff
/sbin/shutdown
/sbin/telinit
/sbin/runlevel
%{_mandir}/man1/init.*
%{_mandir}/man8/halt.*
%{_mandir}/man8/reboot.*
%{_mandir}/man8/shutdown.*
%{_mandir}/man8/poweroff.*
%{_mandir}/man8/telinit.*
%{_mandir}/man8/runlevel.*


%changelog
* Thu Feb 17 2011 dmorgan <dmorgan> 18-1.mga1
+ Revision: 52867
- Fix file list
- New version
  Remove patch15: Merged upstream

* Sat Feb 12 2011 spuhler <spuhler> 17-2.mga1
+ Revision: 51174
- initial import
- removed Patch14:	systemd-17-hwclock-hctosys.patch
  added Patch15:	systemd-17-fix-cgroup.patch
- added patch 14
- added Requires: systemd-units = %%{EVRD}
  added +Patch14:   systemd-17-hwclock-hctosys.patch
- removed buildroot definition from .spec
  put buildrequires each in one line

  + dmorgan <dmorgan>
    - Use fedora as distro name as mageia is not yet defined
    - Fix distro name
    - Merge mdv commit 634092
    - New version 17
    - Remove old binaries
    - Sync with mdv

* Mon Jan 17 2011 blino <blino> 15-5.mga1
+ Revision: 21515
- adapt requires
- rename /etc/release patch
- use /etc/release file
- imported package systemd


* Tue Dec 28 2010 Eugeni Dodonov <eugeni@mandriva.com> 15-4mdv2011.0
+ Revision: 625680
- Allow systemd to be installed instead of sysvinit.

* Fri Dec 03 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 15-3mdv2011.0
+ Revision: 606522
- use native shutdown services

* Fri Dec 03 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 15-2mdv2011.0
+ Revision: 605806
- P13: use /etc/mandriva-release for welcome message
- correctly disable systemd-random-seed-load.service for now
- restore systemd-update-utmp-runlevel.service

* Wed Dec 01 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 15-1mdv2011.0
+ Revision: 604583
- update to v15
- drop P2, P8: units provided by initscripts now
- rediff P4, P5
- drop P9, P10, P11: upstream
- P12: support build with libnotify < 0.7 (GIT); BR automake/autoconf
- /etc/init.d/reboot provided by initscripts now
- session* became user* now
- systemd-ask-password-agent => systemd-gnome-ask-password-agent
- for now remove most of native services from default activation
- drop docbook/xslt BR
- require recent enough initscripts

* Tue Nov 30 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 11-7mdv2011.0
+ Revision: 603786
- for now remove services installed or provided by initscripts package

* Sun Nov 28 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 11-6mdv2011.0
+ Revision: 602332
- require initscripts >= 9.21
- drop P0, use /sys/fs/cgroup (needs kernel 2.6.36)
- drop P3, S1; use /etc/init.d/halt from initscripts now
- patch1: drop, not needed with new docbook-style-xsl

* Sat Nov 06 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 11-5mdv2011.0
+ Revision: 593996
- patch6: do not disable reading of /etc/locale.conf

* Tue Nov 02 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 11-4mdv2011.0
+ Revision: 592331
- patch11: fix device ACLs after systemd installation
- patch10: fix startup with IPv6 disabled

* Mon Oct 25 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 11-3mdv2011.0
+ Revision: 589354
- yet another attempt to get update scripts right
- patch9: fix systemctl enable getty@.service (upstream)

* Sat Oct 16 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 11-2mdv2011.0
+ Revision: 586020
- patch8: fix entering single user mode, revert to /bin/sh

* Sat Oct 16 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 11-1mdv2011.0
+ Revision: 585969
- source1: remove some actions now performed by systemd units
- disable MountAuto and SwapAuto (Fedora)
- re-exec daemon on glibc and self update
- disable more services from rc.sysinit
- patch7: break loop between network.target and network-up.sevice
- for now disable services performed by initscripts
- getty.target is now enabled by default
- patch6: Mandriva support in locale setup
- patch5: Mandriva support in keyboard setup
- move /etc/systemd/system.conf, /bin/systemctl in main package; they are
  usable without units. Remove duplicated LICENSE inclusion.
- new version

* Sat Sep 18 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 10-7mdv2011.0
+ Revision: 579679
- patch4: use messagebus for special D-Bus service for now
- source1, patch3: local version of halt script that does not unmount cgroup
- do not enable prefdm.service, we start display manager in initscirpt
- fix syslog-service
- /etc/systemd and /lib/systemd should be owned by main package

* Sat Sep 18 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 10-6mdv2011.0
+ Revision: 579486
- fix postinstallation script to create default links

* Thu Sep 16 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 10-5mdv2011.0
+ Revision: 579036
- patch2: fix shutdown/reboot with legacy /sbin/halt

* Wed Sep 15 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 10-4mdv2011.0
+ Revision: 578750
- do not delete *.wanted files; getty does not start without them
- set distro to fedora for now; too much is missing with 'other'

* Wed Sep 15 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 10-3mdv2011.0
+ Revision: 578704
- it's _initrddir, not _initdir

* Wed Sep 15 2010 Andrey Borzenkov <arvidjaar@mandriva.org> 10-2mdv2011.0
+ Revision: 578688
- patch1: fix man pages rebuild after patch0
- patch0: use /cgroup until /sys/fs/cgroup is supported by kernel
- runlevelN.target are in /lib now
- remove Requires: libudev, it is computed automatically

* Wed Sep 15 2010 Tomasz Pawel Gajc <tpg@mandriva.org> 10-1mdv2011.0
+ Revision: 578379
- prepare to release as dbus was updated to 1.4.0 version
- fix file list
- import systemd

  + Andrey Borzenkov <arvidjaar@mandriva.org>
    - new version

